@@ -3,6 +3,7 @@
 namespace Wallabag\CoreBundle\Form\Type;
 
 use Symfony\Component\Form\AbstractType;
+use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
 use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
 use Symfony\Component\Form\Extension\Core\Type\IntegerType;
 use Symfony\Component\Form\Extension\Core\Type\SubmitType;
@@ -12,42 +13,28 @@ use Wallabag\CoreBundle\Entity\Config;
 
 class ConfigType extends AbstractType
 {
-    private $themes = [];
     private $languages = [];
 
     /**
-     * @param array $themes    Themes come from the LiipThemeBundle (liip_theme.themes)
      * @param array $languages Languages come from configuration, array just code language as key and label as value
      */
-    public function __construct($themes, $languages)
+    public function __construct($languages)
     {
-        $this->themes = array_combine(
-            $themes,
-            array_map(function ($s) {
-                $cleanTheme = ucwords(strtolower(str_replace('-', ' ', $s)));
-
-                if ('Baggy' === $cleanTheme) {
-                    $cleanTheme = 'Baggy (DEPRECATED)';
-                }
-
-                return $cleanTheme;
-            }, $themes)
-        );
-
         $this->languages = $languages;
     }
 
     public function buildForm(FormBuilderInterface $builder, array $options)
     {
         $builder
-            ->add('theme', ChoiceType::class, [
-                'choices' => array_flip($this->themes),
-                'label' => 'config.form_settings.theme_label',
-            ])
             ->add('items_per_page', IntegerType::class, [
                 'label' => 'config.form_settings.items_per_page_label',
                 'property_path' => 'itemsPerPage',
             ])
+            ->add('display_thumbnails', CheckboxType::class, [
+                'label' => 'config.form_settings.display_thumbnails_label',
+                'property_path' => 'displayThumbnails',
+                'required' => false,
+            ])
             ->add('reading_speed', IntegerType::class, [
                 'label' => 'config.form_settings.reading_speed.label',
                 'property_path' => 'readingSpeed',
@@ -77,7 +64,7 @@ class ConfigType extends AbstractType
     public function configureOptions(OptionsResolver $resolver)
     {
         $resolver->setDefaults([
-            'data_class' => 'Wallabag\CoreBundle\Entity\Config',
+            'data_class' => Config::class,
         ]);
     }
 
