@@ -7,6 +7,7 @@ use Symfony\Component\Form\Extension\Core\Type\SubmitType;
 use Symfony\Component\Form\Extension\Core\Type\TextType;
 use Symfony\Component\Form\FormBuilderInterface;
 use Symfony\Component\OptionsResolver\OptionsResolver;
+use Wallabag\CoreBundle\Entity\IgnoreOriginInstanceRule;
 
 class IgnoreOriginInstanceRuleType extends AbstractType
 {
@@ -26,7 +27,7 @@ class IgnoreOriginInstanceRuleType extends AbstractType
     public function configureOptions(OptionsResolver $resolver)
     {
         $resolver->setDefaults([
-            'data_class' => 'Wallabag\CoreBundle\Entity\IgnoreOriginInstanceRule',
+            'data_class' => IgnoreOriginInstanceRule::class,
         ]);
     }
 
