@@ -4,19 +4,16 @@ namespace Wallabag\CoreBundle\Helper;
 
 use Pagerfanta\Adapter\AdapterInterface;
 use Pagerfanta\Pagerfanta;
-use Symfony\Component\Routing\Router;
 use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;
 use Wallabag\UserBundle\Entity\User;
 
 class PreparePagerForEntries
 {
-    private $router;
     private $tokenStorage;
 
-    public function __construct(TokenStorageInterface $tokenStorage, Router $router)
+    public function __construct(TokenStorageInterface $tokenStorage)
     {
         $this->tokenStorage = $tokenStorage;
-        $this->router = $router;
     }
 
     /**
@@ -30,7 +27,7 @@ class PreparePagerForEntries
             $user = $this->tokenStorage->getToken() ? $this->tokenStorage->getToken()->getUser() : null;
         }
 
-        if (null === $user || !\is_object($user)) {
+        if (!$user instanceof User) {
             return;
         }
 
