@@ -2,9 +2,7 @@
 
 namespace Wallabag\ImportBundle\DependencyInjection;
 
-use Symfony\Component\Config\FileLocator;
 use Symfony\Component\DependencyInjection\ContainerBuilder;
-use Symfony\Component\DependencyInjection\Loader;
 use Symfony\Component\HttpKernel\DependencyInjection\Extension;
 
 class WallabagImportExtension extends Extension
@@ -15,9 +13,6 @@ class WallabagImportExtension extends Extension
         $config = $this->processConfiguration($configuration, $configs);
         $container->setParameter('wallabag_import.allow_mimetypes', $config['allow_mimetypes']);
         $container->setParameter('wallabag_import.resource_dir', $config['resource_dir']);
-
-        $loader = new Loader\YamlFileLoader($container, new FileLocator(__DIR__ . '/../Resources/config'));
-        $loader->load('services.yml');
     }
 
     public function getAlias()
